parse_file_cached

Function parse_file_cached 

pub fn parse_file_cached(
    text: &str,
    kind: FileKind,
    cache: &mut ChameleonCache,
) -> Parse
parse_file for callers re-parsing similar text: the result is identical, but lazy blocks, lambdas and KDoc whose text was already seen with cache are reused instead of re-parsed.